@@ -208,16 +208,12 @@ class MintBackup:
         accel_group = Gtk.AccelGroup()
         self.main_window.add_accel_group(accel_group)
         menu = self.builder.get_object("main_menu")
-        item = Gtk.ImageMenuItem()
-        item.set_image(Gtk.Image.new_from_icon_name("help-about-symbolic", Gtk.IconSize.MENU))
-        item.set_label(_("About"))
+        item = Gtk.ImageMenuItem(label=_("About"), image=Gtk.Image(icon_name="help-about-symbolic", icon_size=Gtk.IconSize.MENU))
         item.connect("activate", self.open_about)
         key, mod = Gtk.accelerator_parse("F1")
         item.add_accelerator("activate", accel_group, key, mod, Gtk.AccelFlags.VISIBLE)
         menu.append(item)
-        item = Gtk.ImageMenuItem(label=_("Quit"))
-        image = Gtk.Image.new_from_icon_name("application-exit-symbolic", Gtk.IconSize.MENU)
-        item.set_image(image)
+        item = Gtk.ImageMenuItem(label=_("Quit"), image=Gtk.Image(icon_name="application-exit-symbolic", icon_size=Gtk.IconSize.MENU))
         item.connect('activate', lambda widget: self.main_window.destroy())
         key, mod = Gtk.accelerator_parse("<Control>Q")
         item.add_accelerator("activate", accel_group, key, mod, Gtk.AccelFlags.VISIBLE)
